# -*- encoding: utf-8 -*-
"""
    keys

    string constants
"""

ALLOW_SOURCE = 'allow_source'
BROADCASTS = 'broadcasts'
CHANNEL = 'channel'
CLIENT_ID = 'client_id'
DIRECTION = 'direction'
ERROR = 'error'
FEATURED = 'featured'
FOLLOWS = 'follows'
GAME = 'game'
HLS = 'hls'
ID = 'id'
LIMIT = 'limit'
LIVE = 'live'
MESSAGE = 'message'
NAUTH = 'nauth'
NAUTHSIG = 'nauthsig'
OFFSET = 'offset'
PERIOD = 'period'
QUERY = 'query'
SIG = 'sig'
SORT_BY = 'sortby'
TARGET = 'target'
TEAM = 'team'
TOKEN = 'token'
TYPE = 'type'
USER = 'user'
USER_AGENT = 'User-Agent'
USER_AGENT_STRING = ('Mozilla/5.0 (Windows NT 6.1; WOW64; rv:6.0) '
                     'Gecko/20100101 Firefox/6.0')
VOD = 'vod'
